==> free-1.4.tar.gz: FREE-1.4/Free/TimeOutThread.java <==
/*
 * FREE 2000
 *
 * Copyright (c) Jason Kitcat, University of Warwick
 *
 * jeep@thecouch.org   http://www.thecouch.org/free/
 *
 * Knoll Cottage, Sutton Place, Nr.Abinger, Dorking, Surrey RH5 6RN United Kingdom
 *
 * Tel: 07956 886 508  Fax: 0870 052 7114
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
  
package Free;
 
/**
 * A simple thread which waits a certain time in milliseconds defined by
 * <code>RTServer.timeOutTime</code> before closing communications.
 *
 * @version 0.4  11 November 2000
 * @author Jason Kitcat
 */
public class TimeOutThread extends Thread {

	public boolean threadStatus = true;

	public void stopThread() {
		threadStatus = false;
	}

	public void run() {
	
		while (threadStatus) {

			try {
				sleep(RTServer.timeOutTime);
			} catch (InterruptedException e) {}
		
			RTServer.carryOn = false;
			RTServer.NORM.error("Connection timed out.");
		
		} //eof while
		
	} //EOF run()


} //EOF TimeOutThread

==> free-1.5.tar.gz: FREE-1.5/Free/TimeOutThread.java <==
/*
 * GNU.FREE 2001
 *
 * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
 *
 * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
 *
 * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
 * 
 * FREE e-democracy site: http://www.thecouch.org/free/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
  
package Free;
 
/**
 * A simple thread which waits a certain time in milliseconds defined by
 * <code>RTServer.timeOutTime</code> before closing communications.
 *
 * @version 0.6  26 February 2001
 * @author Jason Kitcat
 */
public class TimeOutThread extends Thread {

	public boolean threadStatus = true;

	public void stopThread() {
		threadStatus = false;
	}

	public void run() {
	
		while (threadStatus) {

			try {
				sleep(RTServer.timeOutTime);
			} catch (InterruptedException e) {}
		
			if (threadStatus) {
				RTServer.carryOn = false;
				RTServer.NORM.error("Connection timed out.");
				RTServer.frame.jButton1.setEnabled(false);
				RTServer.NORM.error("Press End Vote again to retry.");
			}
		
		} //eof while
		
	} //EOF run()


} //EOF TimeOutThread
